use std::{
    env::{self, set_var},
    io::Read,
    path::PathBuf,
};

use tracing::info;

// Load environment variables from a .env file without external dependencies
pub fn load_dot_env() {
    let mut d = PathBuf::from(env::current_dir().unwrap());
    d.push(".env");
    if !d.exists() {
        info!("No .env file found");
        return;
    }
    if let Ok(mut file) = std::fs::File::open(d) {
        let mut contents = String::new();
        if file.read_to_string(&mut contents).is_ok() {
            for line in contents.lines() {
                if line.is_empty() || line.starts_with('#') {
                    continue; // Skip empty lines and comments
                }
                if let Some((key, value)) = line.split_once('=') {
                    unsafe { set_var(key.trim(), value.trim().replace("\"", "")) };
                }
            }
        }
        info!("Loaded .env file");
    } else {
        info!("Failed to open .env file");
    }
}
